Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(388)

Unified Diff: components/sync/engine/engine_components_factory.h

Issue 2413313004: [Sync] Move the last things out of core/. (Closed)
Patch Set: Created 4 years, 2 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: components/sync/engine/engine_components_factory.h
diff --git a/components/sync/core/internal_components_factory.h b/components/sync/engine/engine_components_factory.h
similarity index 89%
rename from components/sync/core/internal_components_factory.h
rename to components/sync/engine/engine_components_factory.h
index 779415d0d8a414c60b59c605347b28615512ab88..2a7345a8ec361b37412291b3d08080f238b4b1a3 100644
--- a/components/sync/core/internal_components_factory.h
+++ b/components/sync/engine/engine_components_factory.h
@@ -2,12 +2,12 @@
// Use of this source code is governed by a BSD-style license that can be
// found in the LICENSE file.
//
// InternalComponentsFactory exists so that tests can override creation of
// components used by the SyncManager that are not exposed across the sync
// API boundary.
-#ifndef COMPONENTS_SYNC_CORE_INTERNAL_COMPONENTS_FACTORY_H_
-#define COMPONENTS_SYNC_CORE_INTERNAL_COMPONENTS_FACTORY_H_
+#ifndef COMPONENTS_SYNC_ENGINE_ENGINE_COMPONENTS_FACTORY_H_
+#define COMPONENTS_SYNC_ENGINE_ENGINE_COMPONENTS_FACTORY_H_
#include <memory>
#include <string>
@@ -32,7 +32,7 @@ class Directory;
class DirectoryBackingStore;
}
-class InternalComponentsFactory {
+class EngineComponentsFactory {
skym 2016/10/14 18:42:13 This class needs a comment. You're in the best pos
maxbogue 2016/10/14 20:25:00 Done.
public:
enum EncryptionMethod {
ENCRYPTION_LEGACY,
@@ -61,7 +61,7 @@ class InternalComponentsFactory {
// Configuration options for internal components. This struct is expected
// to grow and shrink over time with transient features / experiments,
// roughly following command line flags in chrome. Implementations of
// InternalComponentsFactory can use this information to build components
// with appropriate bells and whistles.
struct Switches {
EncryptionMethod encryption_method;
@@ -81,7 +81,7 @@ class InternalComponentsFactory {
STORAGE_INVALID
};
- virtual ~InternalComponentsFactory() {}
+ virtual ~EngineComponentsFactory() {}
virtual std::unique_ptr<SyncScheduler> BuildScheduler(
const std::string& name,
@@ -109,4 +109,4 @@ class InternalComponentsFactory {
} // namespace syncer
-#endif // COMPONENTS_SYNC_CORE_INTERNAL_COMPONENTS_FACTORY_H_
+#endif // COMPONENTS_SYNC_ENGINE_ENGINE_COMPONENTS_FACTORY_H_

Powered by Google App Engine
This is Rietveld 408576698
@@ -2,12 +2,12 @@
// found in the LICENSE file.
//
-// InternalComponentsFactory exists so that tests can override creation of
+// EngineComponentsFactory exists so that tests can override creation of
// components used by the SyncManager that are not exposed across the sync
// API boundary.
@@ -61,7 +61,7 @@ class InternalComponentsFactory {
// to grow and shrink over time with transient features / experiments,
// roughly following command line flags in chrome. Implementations of
- // InternalComponentsFactory can use this information to build components
+ // EngineComponentsFactory can use this information to build components
// with appropriate bells and whistles.
struct Switches {